const createPropWithLangs = (prop, langs, emptyValue = null) => {
    const result = {};

    if (Array.isArray(langs)) {
        langs.forEach((lang) => {
            result[`${prop}_${lang}`] = emptyValue;
        });
    }

    return result;
};

const createPropsWithLangs = (props, langs) => {
    let result = {};

    if (props && Array.isArray(langs)) {
        Object.entries(props).forEach(([prop, emptyValue]) => {
            const piece = createPropWithLangs(prop, langs, emptyValue);
            if (typeof piece === 'object') {
                result = {
                    ...result,
                    ...piece,
                };
            }
        });
    }

    return result;
};

const createDefaultValuesByLang = (name, source, langs) => {
    if (typeof source !== 'object') {
        console.error('Source must be an object');

        return {};
    }

    const values = {};
    langs.forEach((lang) => {
        values[lang] = source[`${name}_${lang}`];
    });

    return values;
};

export { createPropWithLangs, createPropsWithLangs, createDefaultValuesByLang };

